@@ -20,7 +20,9 @@ class LaunchableClientFactory:
 
     @classmethod
     def _parse_options(cls):
-        token = os.environ[cls.TOKEN_KEY]
+        token = os.environ.get(cls.TOKEN_KEY)
+        if token is None:
+            raise Exception("%s not set"%cls.TOKEN_KEY)
 
         _, user, _ = token.split(":", 2)
         org, workplace = user.split("/", 1)
@@ -64,31 +66,20 @@ class LaunchableClient:
 
         self.test_session_id = response_body['id']
 
-    def reorder(self, test):
-        url = "{}/intake/organizations/{}/workspaces/{}/inference".format(
-            self.base_url,
-            self.org_name,
-            self.workspace_name
-        )
-
-        request_body = self._reorder_request_body(test)
-
-        logger.debug("Request body: {}".format(request_body))
-
-        res = self.http.post(url, headers=self._headers(), json=request_body)
-        logger.debug("Response status code: {}".format(res.status_code))
-        res.raise_for_status()
-
-        response_body = res.json()
-        logger.debug("Response body: {}".format(response_body))
-
-        return response_body
-
-    def subset(self, test_names, target):
+    def subset(self, test_names, options, target):
         url = "/test_sessions/{}".format(self.test_session_id)
 
+        cmd = ['launchable', 'subset', '--session', url]
+        if options is not None:
+            cmd.extend([option.strip() for option in options.split(' ')])
+            cmd.append('file')
+        else:
+            cmd.extend(['--target', target + '%', 'file'])
+
+        logger.debug("Subset command: {}".format(cmd))
+
         proc = self.process.run(
-            ['launchable', 'subset', '--session', url, '--target', target + '%', 'file'],
+            cmd,
             input="\n".join(test_names),
             encoding='utf-8',
             stdout=self.process.PIPE,
@@ -140,11 +131,5 @@ class LaunchableClient:
             'Authorization': 'Bearer {}'.format(self.token)
         }
 
-    def _reorder_request_body(self, test):
-        return {
-            "test": test,
-            "session": {"id": self.test_session_id, "subject": self.build_number, "flavors": {}},
-        }
-
     def _upload_request_body(self, events):
         return {"events": [event.to_body() for event in events]}
