@@ -1,4 +1,3 @@
-
 import os
 import sys
 from io import StringIO
@@ -11,8 +10,8 @@ from nose.plugins.xunit import Tee
 from nose_launchable.case_event import CaseEvent
 from nose_launchable.client import LaunchableClientFactory
 from nose_launchable.log import logger
-from nose_launchable.manager import parse_test, get_test_names, reorder, subset, get_test_path
-from nose_launchable.protecter import protect
+from nose_launchable.manager import get_test_names, subset, get_test_path
+from nose_launchable.protecter import protect, handleError
 from nose_launchable.uploader import UploaderFactory
 
 BUILD_NUMBER_KEY = "LAUNCHABLE_BUILD_NUMBER"
@@ -33,58 +32,76 @@ class Launchable(Plugin):
 
     def options(self, parser, env):
         super(Launchable, self).options(parser, env=env)
-        parser.add_option("--launchable", action='store_true', dest="enabled", help="Enable Launchable reordering")
-        parser.add_option("--launchable-reorder", action='store_true', dest="reorder_enabled", help="Enable Launchable reordering")
-        parser.add_option("--launchable-subset", action='store_true', dest="subset_enabled", help="Enable Launchable subsetting")
-        parser.add_option("--launchable-build-number", action='store', type='string', dest="build_number", help="CI/CD build number")
-        parser.add_option("--launchable-subset-target", action='store', type='string', dest="subset_target", help="Target percentage of subset")
+        parser.add_option("--launchable-subset", action='store_true', dest="subset_enabled",
+                          help="Enable Launchable subsetting")
+        parser.add_option("--launchable-build-number", action='store', type='string', dest="build_number",
+                          help="CI/CD build number")
+        parser.add_option("--launchable-subset-target", action='store', type='string', dest="subset_target",
+                          help="Target percentage of subset")
+
+        parser.add_option("--launchable-subset-options", action='store', dest="subset_options",
+                          help="Launchable CLI subset command options")
+
+        parser.add_option("--launchable-record-only", action='store_true', dest="record_only_enabled",
+                          help="Enable Launchable recording")
 
     def configure(self, options, conf):
         super(Launchable, self).configure(options, conf)
 
-        self.reorder_enabled = options.enabled or options.reorder_enabled or False
         self.subset_enabled = options.subset_enabled or False
+        self.record_only_enabled = options.record_only_enabled or False
+
         self.build_number = options.build_number or os.getenv(BUILD_NUMBER_KEY)
         self.subset_target = options.subset_target
+        self.subset_options = options.subset_options
 
-        if not (self.reorder_enabled ^ self.subset_enabled):
-            self.enabled = False
-            logger.warning("Please specify either --launchable-reorder flag or --launchable-subset flag")
+        if not (self.subset_enabled or self.record_only_enabled):
+            # we didn't get activated
             return
 
+        if os.environ.get(LaunchableClientFactory.TOKEN_KEY) is None:
+            logger.warning("%s not set. Deactivating"%LaunchableClientFactory.TOKEN_KEY)
+            return
+
+        if self.subset_enabled and self.record_only_enabled:
+            logger.warning("Please specify either --launchable-subset or --launchable-record-only flag")
+            return
+
+        if self.build_number is None:
+            logger.warning("Please specify --launchable-build-number flag")
+            return
+
+        if self.subset_enabled and not ((self.subset_target is None) ^ (self.subset_options is None)):
+            logger.warning("Please specify either --launchable-subset-target or --launchable-subset-options flag")
+            return
+
+        try:
+            self._client = LaunchableClientFactory.prepare()
+            self._uploader = UploaderFactory.prepare(self._client)
+        except Exception as e:
+            handleError(e)
+            return
+
+        # only if every validation checks out we are good to go
         self.enabled = True
 
-        if self.enabled and self.build_number is None:
-            self.enabled = False
-            logger.warning("Please specify --launchable-build-number flag in order to enable nose-launchable plugin")
-
-        if self.subset_enabled and self.subset_target is None:
-            self.enabled = False
-            logger.warning("Please specify --launchable-subset-target flag to run subset")
-
 
     @protect
     def begin(self):
-        self._client = LaunchableClientFactory.prepare()
         self._client.start(self.build_number)
-
-        self._uploader = UploaderFactory.prepare(self._client)
-
         self._uploader.start()
 
     @protect
     def prepareTest(self, test):
-        self._print("Getting optimized test execution order from Launchable...\n")
-        if self.reorder_enabled:
-            self._reorder(test)
-
         if self.subset_enabled:
+            self._print("Getting optimized test execution order from Launchable...\n")
+
             self._subset(test)
 
-        self._print("Test execution optimized by Launchable ")
-        # A rocket emoji
-        self._print("\U0001f680\n")
-        return test
+            self._print("Test execution optimized by Launchable ")
+            # A rocket emoji
+            self._print("\U0001f680\n")
+            return test
 
     @protect
     def startContext(self, context):
@@ -128,20 +145,14 @@ class Launchable(Plugin):
         self._uploader.join()
         self._client.finish()
 
-    def _reorder(self, test):
-        tree = parse_test(test)
-
-        order = self._client.reorder(tree)
-
-        reorder(test, order)
+        self._print("Test results have been successfully uploaded to Launchable\n")
 
     def _subset(self, test):
         test_names = get_test_names(test)
 
-        order = self._client.subset(test_names, self.subset_target)
+        targets = self._client.subset(test_names, self.subset_options, self.subset_target)
 
-        # Create a dictionary maps test_name to its index
-        subset(test, {o: i for i, o in enumerate(order)})
+        subset(test, set(targets))
 
     def _startCapture(self):
         self._capture_stack.append((sys.stdout, sys.stderr))
